import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import MultiSelectBlock from 'molecules/MultiSelectBlock';
import { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';

/**
 * Block of select view.
 *
 * @param
 */
const UrlMultiSelectBlock = ({ label, value, setValue, url, cloudContext, required }: {
  label: string,
  value: string[],
  setValue: (s: string[]) => void,
  url: string,
  cloudContext: string,
  required: boolean,
}) => {

  const params: {
    cloudServiceProvider: string,
    cloudContext: string,
    entityName: string,
    entityId: string,
    action: string
  } = useParams();

  const { getJsonData } = useDrupalJsonApi();
  const [recordList, setRecordList] = useState<{ value: string, label: string, group?: string }[]>([]);

  useEffect(() => {
    let replacedUrl = url
      .replace('{cloud_context}', cloudContext)
      .replace('{entity_id}', params.entityId);
    getJsonData<{ value: string, label: string, group?: string }[]>(replacedUrl).then((jsonData) => {
      setRecordList(jsonData);
    })
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [cloudContext]);

  return <MultiSelectBlock
    label={label}
    value={value}
    setValue={setValue}
    recordList={recordList}
    required={required} />;
}

export default UrlMultiSelectBlock;
