import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import LabelBlock from 'molecules/LabelBlock';
import SelectBlock from 'molecules/SelectBlock';
import { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';

/**
 * Block of select view.
 *
 * @param
 */
const UrlSelectBlock = ({ label, value, setValue, url, cloudContext, required, readOnly }: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  url: string,
  cloudContext: string,
  required: boolean,
  readOnly: boolean,
}) => {

  const params: {
    cloudServiceProvider: string,
    cloudContext: string,
    entityName: string,
    entityId: string,
    action: string
  } = useParams();

  const { getJsonData } = useDrupalJsonApi();
  const [recordList, setRecordList] = useState<{ value: string, label: string, group?: string }[]>([]);

  useEffect(() => {
    let replacedUrl = url
      .replace('{cloud_context}', cloudContext)
      .replace('{entity_id}', params.entityId);
    getJsonData<{ value: string, label: string, group?: string }[]>(replacedUrl).then((jsonData) => {
      setRecordList(jsonData);
    })
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [cloudContext]);

  if (readOnly) {
    const filtered = recordList.filter((r) => r.value === value);
    return <LabelBlock
      name={label}
      value={filtered.length >= 1 ? filtered[0].label : value} />;
  }

  return <SelectBlock
    label={label}
    value={value}
    setValue={setValue}
    recordList={recordList}
    required={required} />;
}

export default UrlSelectBlock;
