import PanelWrapper from 'atoms/PanelWrapper';
import EntityFormRecord from 'model/EntityFormRecord';
import EntityFormBlock from 'molecules/EntityFormBlock';
import { calcPanelName } from 'service/utility';

/**
 * Determines whether or not to display the form.
 *
 * Some pages require fine control over the display of forms.
 * Therefore, this function determines whether or not to display the form.
 * @param cloudServiceProvider The cloud service provider.
 * @param entityName The entity's type name.
 * @param actionType The CxUD action Type.
 * @param labelName The label name of this form block.
 * @param formData The data of form values.
 *
 * @returns If TRUE, the block is displayed.
 */
const showEntityFormBlockFlg = (
  cloudServiceProvider: string,
  entityName: string,
  actionType: string,
  labelName: string,
  formData: Record<string, any>
) => {
  // Create K8s deployment
  if (actionType === 'create'
    && cloudServiceProvider === 'k8s'
    && entityName === 'deployment') {
    if (labelName === 'Detail') {
      return formData['time_scheduler_option'] === 'cloud_orchestrator_scheduler';
    }
    if (labelName === 'YAML URL') {
      return formData['time_scheduler_option'] === 'cronjob_scheduler';
    }
    if (['Scheduler Use Type', 'Start-up Time', 'Stop Time'].includes(labelName)) {
      return formData['enableTimeScheduler'];
    }
  }

  // Create K8s pod
  if (actionType === 'create'
    && cloudServiceProvider === 'k8s'
    && entityName === 'pod') {
    if (labelName === 'Detail') {
      return formData['time_scheduler_option'] === 'cloud_orchestrator_scheduler';
    }
    if (labelName === 'YAML URL') {
      return formData['time_scheduler_option'] === 'cronjob_scheduler';
    }
    if (['Scheduler Use Type', 'Start-up Time', 'Stop Time'].includes(labelName)) {
      return formData['enableTimeScheduler'];
    }
  }

  return true;
}

const EntityFormPanel = ({
  cloudServiceProvider,
  cloudContext,
  entityName,
  actionType,
  entityRecord,
  formData,
  setFormData
}: {
  cloudServiceProvider: string,
  cloudContext: string,
  entityName: string,
  actionType: string,
  entityRecord: EntityFormRecord,
  formData: Record<string, any>,
  setFormData: (f: Record<string, any>) => void,
}) => {
  if (entityRecord.type !== 'panel') {
    return <></>;
  }

  return <PanelWrapper title={calcPanelName(entityRecord.panelName, entityName)}>
    {
      entityRecord.keyValueRecords.map((keyValueRecord, index) => {
        return (showEntityFormBlockFlg(
          cloudServiceProvider,
          entityName,
          actionType,
          keyValueRecord.labelName,
          formData
        ))
          ? <EntityFormBlock key={index}
            keyValueRecord={keyValueRecord}
            cloudContext={cloudContext}
            formData={formData}
            setFormData={setFormData} />
          : <></>;
      })
    }
  </PanelWrapper>;
}

export default EntityFormPanel;
