<?php

namespace Drupal\aws_cloud\Form\Ec2;

use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for the CloudScripting entity edit forms.
 *
 * @ingroup aws_cloud
 */
class KeyPairEditForm extends AwsCloudContentForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $cloud_context = '') {
    /** @var \Drupal\aws_cloud\Entity\Ec2\KeyPair $entity */
    $form = parent::buildForm($form, $form_state);

    $entity = $this->entity;
    if (!$this->updateEntityBuildForm($entity)) {
      return $this->redirectUrl;
    }

    $weight = -50;

    $form['key_pair'] = [
      '#type' => 'details',
      '#title' => $this->t('Key pair'),
      '#open' => TRUE,
      '#weight' => $weight++,
    ];

    $form['key_pair']['key_pair_name'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Key pair name')),
      '#markup'        => $entity->getKeyPairName(),
    ];

    $form['key_pair']['key_pair_id'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Key pair ID')),
      '#markup'        => $entity->getKeyPairId(),
    ];

    $form['key_pair']['key_fingerprint'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Fingerprint')),
      '#markup'        => $entity->getKeyFingerprint(),
    ];

    $form['key_pair']['created'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('Created')),
      '#markup'        => $this->dateFormatter->format($entity->created(), 'short'),
    ];

    $this->addOthersFieldset($form, $weight++, $cloud_context);

    $form['actions'] = $this->actions($form, $form_state, $cloud_context);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state): void {
    // Call copyFormItemValues() to ensure the form array is intact.
    $this->copyFormItemValues($form);

    $this->trimTextfields($form, $form_state);

    $entity = $this->entity;

    $bundle = str_contains($entity->bundle(), 'aws_cloud')
      ? 'aws_cloud' : 'openstack';

    $uid_key_name = $this->cloudService->getTagCreatedByUid(
      $bundle,
      $entity->getCloudContext());

    $this->ec2Service->setCloudContext($entity->getCloudContext());

    if ($entity->save()) {
      $this->setTagsInAws($entity->getKeyPairName(), [
        $entity->getEntityTypeId() . '_' . $uid_key_name => !empty($entity->getOwner())
        ? $entity->getOwner()->id() : 0,
      ], $entity->getEntityTypeId());
    }

    $this->processOperationStatus($entity, 'updated');
    $this->clearCacheValues($entity->getCacheTags());
    $this->dispatchSaveEvent($entity);
  }

}
