<?php

namespace Drupal\aws_cloud\Form\Vpc;

use Drupal\aws_cloud\Form\Ec2\AwsCloudContentForm;
use Drupal\aws_cloud\Traits\AwsCloudFormTrait;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for the carrier gateway entity create form.
 *
 * @ingroup aws_cloud
 */
class CarrierGatewayCreateForm extends AwsCloudContentForm {

  use AwsCloudFormTrait;

  use CloudContentEntityTrait;

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::buildForm().
   *
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   * @param string $cloud_context
   *   A cloud_context string value from URL "path".
   *
   * @return array
   *   Array of form object.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $cloud_context = ''): array {
    $form = parent::buildForm($form, $form_state);
    $this->ec2Service->setCloudContext($cloud_context);

    $weight = -50;

    $form['carrier_gateway'] = [
      '#type' => 'details',
      '#title' => $this->t('Carrier gateway'),
      '#open' => TRUE,
      '#weight' => $weight++,
    ];

    $form['carrier_gateway']['name'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Name'),
      '#maxlength'     => 255,
      '#size'          => 60,
      '#required'      => TRUE,
    ];

    $vpcs = $this->getVpcOptions($cloud_context);
    natcasesort($vpcs);

    $gateways = $this->entityTypeManager
      ->getStorage('aws_cloud_carrier_gateway')
      ->loadByProperties([
        'cloud_context' => $cloud_context,
      ]);

    foreach ($gateways as $gateway) {
      unset($vpcs[$gateway->getVpcId()]);
    }

    $form['carrier_gateway']['vpc_id'] = [
      '#type'          => 'select',
      '#title'         => $this->t('VPC CIDR (ID)'),
      '#options'       => $vpcs,
      '#default_value' => $this->entity->getVpcId(),
      '#required'      => TRUE,
    ];

    unset($form['tags']);

    $this->addOthersFieldset($form, $weight++, $cloud_context);

    $form['actions'] = $this->actions($form, $form_state, $cloud_context);

    return $form;
  }

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::save().
   *
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @throws \Drupal\Core\Entity\EntityMalformedException
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \Drupal\aws_cloud\Service\Ec2\Ec2ServiceException
   */
  public function save(array $form, FormStateInterface $form_state): void {
    $this->trimTextfields($form, $form_state);

    $cloud_context = $this->routeMatch->getParameter('cloud_context');

    $entity = $this->entity;
    $entity->setCloudContext($cloud_context);

    $form_state->setRedirect(
      'view.aws_cloud_carrier_gateway.list',
      ['cloud_context' => $entity->getCloudContext()]
    );

    $result = $this->ec2Service->createCarrierGateway([
      'VpcId' => $entity->getVpcId(),
    ]);

    if ($result === NULL) {
      $this->processOperationErrorStatus($entity, 'created');
      return;
    }

    if (!empty($result['SendToWorker'])) {
      $this->processOperationStatus($entity, 'created remotely');
      return;
    }

    $entity->setCarrierGatewayId($result['CarrierGateway']['CarrierGatewayId']);
    $entity->save();
    $this->updateNameAndCreatedByTags($entity, $entity->getCarrierGatewayId());

    // Update the carrier gateway.
    $this->ec2Service->updateCarrierGateways([
      'CarrierGatewayIds' => [$entity->getCarrierGatewayId()],
    ], FALSE);

    $this->processOperationStatus($entity, 'created');
    $this->clearCacheValues($entity->getCacheTags());
    $this->dispatchSaveEvent($entity);
  }

}
