<?php

namespace Drupal\k8s\Service\K8sClientExtension;

use Drupal\k8s\Service\K8sClientExtension\Repositories\ApiServiceRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\ClusterRoleBindingRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\ClusterRoleRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\LimitRangeRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\MetricsNodeRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\MetricsPodRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\PriorityClassRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\K8sQuotaRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\StatefulSetRepository;
use Drupal\k8s\Service\K8sClientExtension\Repositories\StorageClassRepository;
use Maclof\Kubernetes\RepositoryRegistry;

/**
 * K8s repository registry.
 */
class K8sRepositoryRegistry extends RepositoryRegistry {

  /**
   * The constructor.
   */
  public function __construct() {
    parent::__construct();

    // Add the repository of api services.
    $this->map['apiServices'] = ApiServiceRepository::class;

    // Add the repository of cluster roles.
    $this->map['clusterRoles'] = ClusterRoleRepository::class;

    // Add the repository of cluster role bindings.
    $this->map['clusterRoleBindings'] = ClusterRoleBindingRepository::class;

    // Change the repository of K8s LimitRanges.
    $this->map['limitRanges'] = LimitRangeRepository::class;

    // Add the repository of metrics nodes.
    $this->map['metricsNodes'] = MetricsNodeRepository::class;

    // Add the repository of metrics pods.
    $this->map['metricsPods'] = MetricsPodRepository::class;

    // Add the repository of priority classes.
    $this->map['priorityClasses'] = PriorityClassRepository::class;

    // Change the repository of quotas.
    $this->map['quotas'] = K8sQuotaRepository::class;

    // Add the repository of storage classes.
    $this->map['storageClasses'] = StorageClassRepository::class;

    // Add the repository of K8s StatefulSets.
    $this->map['statefulSets'] = StatefulSetRepository::class;
  }

}
