<?php

namespace Drupal\openstack\Service;

use Drupal\aws_cloud\Entity\Ec2\ElasticIpInterface;
use Drupal\aws_cloud\Entity\Ec2\ImageInterface;
use Drupal\aws_cloud\Entity\Ec2\InstanceInterface;
use Drupal\aws_cloud\Entity\Ec2\KeyPairInterface;
use Drupal\aws_cloud\Entity\Ec2\NetworkInterfaceInterface;
use Drupal\aws_cloud\Entity\Ec2\SecurityGroupInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides OpenStackOperationsService interface.
 */
interface OpenStackOperationsServiceInterface {

  /**
   * Delete an OpenStack Instance.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\InstanceInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function deleteOpenStackInstance(InstanceInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Create an OpenStack image.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ImageInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function createOpenStackImage(ImageInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Start an OpenStack Instance.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\InstanceInterface $entity
   *   The OpenStack instance entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function startOpenStackInstance(InstanceInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Stop an OpenStack Instance.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\InstanceInterface $entity
   *   The OpenStack instance entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function stopOpenStackInstance(InstanceInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Edit an OpenStack image.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ImageInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function editOpenStackImage(ImageInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Delete an OpenStack image.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ImageInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function deleteOpenStackImage(ImageInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Create an OpenStack KeyPair.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\KeyPairInterface $entity
   *   The OpenStack key pair entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function createOpenStackKeyPair(KeyPairInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Edit an OpenStack KeyPair.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\KeyPairInterface $entity
   *   The OpenStack key pair entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function editOpenStackKeyPair(KeyPairInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Delete an OpenStack KeyPair.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\KeyPairInterface $entity
   *   The OpenStack key pair entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function deleteOpenStackKeyPair(KeyPairInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Create an OpenStack NetworkInterface.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\NetworkInterfaceInterface $entity
   *   The OpenStack network interface entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function createOpenStackNetworkInterface(NetworkInterfaceInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Edit an OpenStack Instance.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\InstanceInterface $entity
   *   The instance entity.
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function editOpenStackInstance(InstanceInterface $entity, array $form, FormStateInterface $form_state): bool;

  /**
   * Delete an OpenStack NetworkInterface.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\NetworkInterfaceInterface $entity
   *   The OpenStack network interface entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function deleteOpenStackNetworkInterface(NetworkInterfaceInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Edit an OpenStack NetworkInterface.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\NetworkInterfaceInterface $entity
   *   The OpenStack network interface entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function editOpenStackNetworkInterface(NetworkInterfaceInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Create an OpenStack floating IP.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ElasticIpInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function createOpenStackFloatingIp(ElasticIpInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Edit an OpenStack floating IP.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ElasticIpInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function editOpenStackFloatingIp(ElasticIpInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Delete an OpenStack floating IP.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ElasticIpInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function deleteOpenStackFloatingIp(ElasticIpInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Create an OpenStack SecurityGroup.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\SecurityGroupInterface $entity
   *   The OpenStack security group entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function createOpenStackSecurityGroup(SecurityGroupInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Delete an OpenStack SecurityGroup.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\SecurityGroupInterface $entity
   *   The OpenStack security group entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function deleteOpenStackSecurityGroup(SecurityGroupInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Revoke an OpenStack SecurityGroup.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\SecurityGroupInterface $entity
   *   The OpenStack security group entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function revokeOpenStackSecurityGroup(SecurityGroupInterface $entity, array &$form, FormStateInterface $form_state): bool;

}
